@@ -178,19 +178,21 @@ namespace Orthanc
       throw OrthancException(ErrorCode_NotImplemented);
     }
 
-    try
+    if (values.HasTag(DICOM_TAG_NUMBER_OF_FRAMES))
     {
-      numberOfFrames_ = boost::lexical_cast<unsigned int>(values.GetValue(DICOM_TAG_NUMBER_OF_FRAMES).GetContent());
+      try
+      {
+        numberOfFrames_ = boost::lexical_cast<unsigned int>(values.GetValue(DICOM_TAG_NUMBER_OF_FRAMES).GetContent());
+      }
+      catch (boost::bad_lexical_cast&)
+      {
+        throw OrthancException(ErrorCode_NotImplemented);
+      }
     }
-    catch (OrthancException&)
+    else
     {
-      // If the tag "NumberOfFrames" is absent, assume there is a single frame
       numberOfFrames_ = 1;
     }
-    catch (boost::bad_lexical_cast&)
-    {
-      throw OrthancException(ErrorCode_NotImplemented);
-    }
 
     if ((bitsAllocated_ != 8 && bitsAllocated_ != 16 && 
          bitsAllocated_ != 24 && bitsAllocated_ != 32) ||
@@ -217,9 +219,19 @@ namespace Orthanc
   {
     if (photometric_ == PhotometricInterpretation_Palette)
     {
-      return false;
-    }
+      if (GetBitsStored() == 8 && GetChannelCount() == 1 && !IsSigned())
+      {
+        format = PixelFormat_RGB24;
+        return true;
+      }
 
+      if (GetBitsStored() == 16 && GetChannelCount() == 1 && !IsSigned())
+      {
+        format = PixelFormat_RGB48;
+        return true;
+      }
+    }
+    
     if (ignorePhotometricInterpretation ||
         photometric_ == PhotometricInterpretation_Monochrome1 ||
         photometric_ == PhotometricInterpretation_Monochrome2)
