@@ -2,6 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
+ * Copyright (C) 2017 Osimis, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,13 +33,14 @@
 
 #pragma once
 
-#include <list>
-#include <string>
-#include <stdint.h>
 #include "../Enumerations.h"
 #include "IHttpOutputStream.h"
 #include "IHttpStreamAnswer.h"
-#include "../Uuid.h"
+
+#include <list>
+#include <string>
+#include <stdint.h>
+#include <map>
 
 namespace Orthanc
 {
