@@ -57,20 +57,24 @@ namespace Orthanc
   }
 
 
+#if ORTHANC_SANDBOXED == 0
   void FontRegistry::AddFromFile(const std::string& path)
   {
     std::auto_ptr<Font> f(new Font);
     f->LoadFromFile(path);
     fonts_.push_back(f.release());
   }
+#endif
 
 
+#if ORTHANC_HAS_EMBEDDED_RESOURCES == 1
   void FontRegistry::AddFromResource(EmbeddedResources::FileResourceId resource)
   {
     std::string content;
     EmbeddedResources::GetFileResource(content, resource);
     AddFromMemory(content);
   }
+#endif
 
 
   const Font& FontRegistry::GetFont(size_t i) const
