@@ -588,12 +588,14 @@ namespace Orthanc
   }
 
 
+#if ORTHANC_HAS_EMBEDDED_RESOURCES == 1
   void LuaContext::Execute(EmbeddedResources::FileResourceId resource)
   {
     std::string command;
     EmbeddedResources::GetFileResource(command, resource);
     ExecuteInternal(NULL, command);
   }
+#endif
 
 
   bool LuaContext::IsExistingFunction(const char* name)
