@@ -2,6 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
+ * Copyright (C) 2017 Osimis, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -59,7 +60,7 @@ namespace Orthanc
       }
 
     public:
-      ReaderLockable(boost::shared_mutex& lock) : lock_(lock)
+      explicit ReaderLockable(boost::shared_mutex& lock) : lock_(lock)
       {
       }
     };
@@ -82,10 +83,9 @@ namespace Orthanc
       }
 
     public:
-      WriterLockable(boost::shared_mutex& lock) : lock_(lock)
+      explicit WriterLockable(boost::shared_mutex& lock) : lock_(lock)
       {
       }
-
     };
   }
 
