@@ -35,7 +35,7 @@
 #include "OrthancRestApi.h"
 
 #include "../../Core/Logging.h"
-#include "../FromDcmtkBridge.h"
+#include "../../Core/DicomParsing/FromDcmtkBridge.h"
 #include "../ServerContext.h"
 #include "../OrthancInitialization.h"
 
@@ -223,7 +223,7 @@ namespace Orthanc
   static bool ParseAnonymizationRequest(DicomModification& target,
                                         RestApiPostCall& call)
   {
-    // curl http://localhost:8042/instances/6e67da51-d119d6ae-c5667437-87b9a8a5-0f07c49f/anonymize -X POST -d '{"Replace":{"PatientName":"hello","0010-0020":"world"},"Keep":["StudyDescription", "SeriesDescription"],"KeepPrivateTags": null,"Remove":["Modality"]}' > Anonymized.dcm
+    // curl http://localhost:8042/instances/6e67da51-d119d6ae-c5667437-87b9a8a5-0f07c49f/anonymize -X POST -d '{"Replace":{"PatientName":"hello","0010-0020":"world"},"Keep":["StudyDescription", "SeriesDescription"],"KeepPrivateTags": true,"Remove":["Modality"]}' > Anonymized.dcm
 
     Json::Value request;
     if (!call.ParseJsonRequest(request) ||
@@ -710,7 +710,7 @@ namespace Orthanc
       }
       else
       {
-        encoding = Configuration::GetDefaultEncoding();
+        encoding = GetDefaultDicomEncoding();
       }
 
       dicom.SetEncoding(encoding);
