@@ -2,6 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
+ * Copyright (C) 2017 Osimis, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -35,7 +36,7 @@
 
 #include "../../Core/Logging.h"
 #include "../../Core/Toolbox.h"
-#include "../../Core/Uuid.h"
+#include "../../Core/TemporaryFile.h"
 
 namespace Orthanc
 {
@@ -59,15 +60,15 @@ namespace Orthanc
       try
       {
         std::string dicom;
-        context_.ReadFile(dicom, *it, FileContentType_Dicom);
+        context_.ReadDicom(dicom, *it);
 
-        Toolbox::TemporaryFile tmp;
+        TemporaryFile tmp;
         tmp.Write(dicom);
 
         std::vector<std::string> args = arguments_;
         args.push_back(tmp.GetPath());
 
-        Toolbox::ExecuteSystemCommand(command_, args);
+        SystemToolbox::ExecuteSystemCommand(command_, args);
 
         // Only chain with other commands if this command succeeds
         outputs.push_back(*it);
