@@ -2,8 +2,9 @@
 # -*- coding: utf-8 -*-
 
 # Orthanc - A Lightweight, RESTful DICOM Store
-# Copyright (C) 2012-2014 Medical Physics Department, CHU of Liege,
-# Belgium
+# Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
+# Department, University Hospital of Liege, Belgium
+# Copyright (C) 2017 Osimis, Belgium
 #
 # This program is free software: you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
 
 
 
-URL = 'http://localhost:8042'
+URL = 'http://127.0.0.1:8042'
 TARGET = 'sample'
 
 
@@ -107,7 +108,7 @@ def Consumer(queue):
                 break
 
         if len(instances) > 0:
-            print 'Sending a packet of %d instances' % len(instances)
+            print('Sending a packet of %d instances' % len(instances))
             start = time.time()
 
             # Send all the instances with a single DICOM connexion
@@ -124,7 +125,7 @@ def Consumer(queue):
             RestToolbox.DoDelete('%s/exports' % URL)
 
             end = time.time()
-            print 'The packet of %d instances has been sent in %d seconds' % (len(instances), end - start)
+            print('The packet of %d instances has been sent in %d seconds' % (len(instances), end - start))
 
 
 #
@@ -133,7 +134,7 @@ def Consumer(queue):
 
 def PrintProgress(queue):
     while True:
-        print 'Current queue size: %d' % (queue.qsize())
+        print('Current queue size: %d' % (queue.qsize()))
         time.sleep(1)
 
 
