@@ -44,6 +44,7 @@
 #include <sqlite3.h>
 #include <lua.h>
 #include <jpeglib.h>
+#include <iconv.h>
 
 #if ORTHANC_ENABLE_SSL == 1
 #include <openssl/opensslv.h>
@@ -103,7 +104,7 @@ TEST(Versions, ZlibStatic)
 
 TEST(Versions, BoostStatic)
 {
-  ASSERT_STREQ("1_64", BOOST_LIB_VERSION);
+  ASSERT_STREQ("1_65_1", BOOST_LIB_VERSION);
 }
 
 TEST(Versions, CurlStatic)
@@ -143,6 +144,13 @@ TEST(Version, LuaStatic)
   ASSERT_STREQ("Lua 5.1.5", LUA_RELEASE);
 }
 
+TEST(Version, LibIconvStatic)
+{
+  static const int major = 1;
+  static const int minor = 15;  
+  ASSERT_EQ((major << 8) + minor, _LIBICONV_VERSION);
+}
+
 
 #if ORTHANC_ENABLE_SSL == 1
 TEST(Version, OpenSslStatic)
